@@ -1,10 +1,10 @@
 #ifndef SPVM_CONSTANT_H
 #define SPVM_CONSTANT_H
 
-#include "spvm_base.h"
+#include "spvm_typedecl.h"
 #include "spvm_native.h"
 
-struct SPVM_constant {
+struct spvm_constant {
   SPVM_OP* op_constant;
   SPVM_TYPE* type;
   SPVM_VALUE value;
